==> spirit_hub-0.0.1.6.tar.gz: spirit_hub-0.0.1.6/e2e/cypress/e2e/features/modals/classify_modal.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is some directories', () => {
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 1' }]]);
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 2' }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
  cy.appFactories([['create', 'tagset_doc', { responsible: '1', tagset_ids: [] }]]);
});

When('I click on the classify button', () => {
  cy.get('#model_table tbody tr:first form[action="/spirit_hub/tagsets/form/classify"] button').click();
});

When('I select the directory {string}', directory => {
  cy.get('label').contains(directory).click();
});

When('I submit the form', () => {
  cy.get('button[data-classify-target="submitButton"]').click();
  cy.waitForTurboResponse();
});

When('I go to the search page', () => {
  cy.get('form[action="/spirit_hub/search"]').submit();
});

Then('The doc status is {string}', status => {
  cy.get('#model_table tbody tr:first td:eq(-2)').contains(status);
});

When('I select the action {string}', action => {
  cy.get('input[name="add_action"]').parent().click();
  cy.get('select[name="next_state_id"]').next('div').click();
  cy.get('.ss-list > div:visible').contains(action).click({ force: true });
});

Then('I see the share modal', () => {
  cy.get('header h2').contains('Partager');
});

When('I share the doc', () => {
  cy.get('select[name="to[]"]').next('div').click();
  cy.get('.ss-list > div:visible').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('button[data-share-form-target="submitButton"]').click();
  cy.waitForTurboResponse();
});

When('I reclassify the doc', () => {
  cy.get('#model_table tbody tr:first td:last div[data-controller="better-dropdown"] button').first().click();
  cy.get('#model_table tbody tr:first td:last div[data-better-dropdown-target="menu"]').contains('Classer').click();
});

Then('I see the existing parent tagset', () => {
  cy.get('#modal').contains('Classement déjà effectué');
});

==> spirit_hub-0.0.1.7.tar.gz: spirit_hub-0.0.1.7/e2e/cypress/e2e/features/modals/classify_modal.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is some directories', () => {
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 1' }]]);
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 2' }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
  cy.appFactories([['create', 'tagset_doc', { responsible: '1', tagset_ids: [] }]]);
});

When('I click on the classify button', () => {
  cy.get('#model_table tbody tr:first form[action="/spirit_hub/tagsets/form/classify"] button').click();
});

When('I select the directory {string}', directory => {
  cy.get('label').contains(directory).click();
});

When('I submit the form', () => {
  cy.get('button[data-classify-form-target="submitButton"]').click();
  cy.waitForTurboResponse();
});

When('I go to the search page', () => {
  cy.get('form[action="/spirit_hub/search"]').submit();
});

Then('I see the share modal', () => {
  cy.get('header h2').contains('Partager');
});

When('I share the doc', () => {
  cy.get('select[name="to[]"]').next('div').click();
  cy.get('.ss-list > div:visible').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('button[data-share-form-target="submitButton"]').click();
  cy.waitForTurboResponse();
});

When('I reclassify the doc', () => {
  cy.get('#model_table tbody tr:first td:last div[data-controller="better-dropdown"] button').first().click();
  cy.get('#model_table tbody tr:first td:last div[data-better-dropdown-target="menu"]').contains('Classer').click();
});

Then('I see the existing parent tagset', () => {
  cy.get('#modal').contains('Classement déjà effectué');
});
